import { Subject } from 'rxjs';
import { PickupGridViewBase } from '@/studio-core';
import HROrganizationService from '@/service/hrorganization/hrorganization-service';
import HROrganizationAuthService from '@/authservice/hrorganization/hrorganization-auth-service';
import PickupGridViewEngine from '@engine/view/pickup-grid-view-engine';
import HROrganizationUIService from '@/uiservice/hrorganization/hrorganization-ui-service';

/**
 * 组织选择表格视图视图基类
 *
 * @export
 * @class HROrganizationPickupGridViewBase
 * @extends {PickupGridViewBase}
 */
export class HROrganizationPickupGridViewBase extends PickupGridViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HROrganizationPickupGridViewBase
     */
    protected appDeName: string = 'hrorganization';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HROrganizationPickupGridViewBase
     */
    protected appDeKey: string = 'organizationid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HROrganizationPickupGridViewBase
     */
    protected appDeMajor: string = 'organizationname';

    /**
     * 实体服务对象
     *
     * @type {HROrganizationService}
     * @memberof HROrganizationPickupGridViewBase
     */
    protected appEntityService: HROrganizationService = new HROrganizationService;

    /**
     * 实体权限服务对象
     *
     * @type HROrganizationUIService
     * @memberof HROrganizationPickupGridViewBase
     */
    public appUIService: HROrganizationUIService = new HROrganizationUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HROrganizationPickupGridViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HROrganizationPickupGridViewBase
     */
    protected model: any = {
        srfCaption: 'entities.hrorganization.views.pickupgridview.caption',
        srfTitle: 'entities.hrorganization.views.pickupgridview.title',
        srfSubTitle: 'entities.hrorganization.views.pickupgridview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HROrganizationPickupGridViewBase
     */
    protected containerModel: any = {
        view_grid: { name: 'grid', type: 'GRID' },
        view_searchform: { name: 'searchform', type: 'SEARCHFORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '07e98f33b8d972b70860e615aaa10b89';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HROrganizationPickupGridViewBase
     */
    public engine: PickupGridViewEngine = new PickupGridViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HROrganizationPickupGridViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            grid: this.$refs.grid,
            searchform: this.$refs.searchform,
            keyPSDEField: 'hrorganization',
            majorPSDEField: 'organizationname',
            isLoadDefault: true,
        });
    }

    /**
     * grid 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROrganizationPickupGridViewBase
     */
    public grid_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'selectionchange', $event);
    }

    /**
     * grid 部件 beforeload 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROrganizationPickupGridViewBase
     */
    public grid_beforeload($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'beforeload', $event);
    }

    /**
     * grid 部件 rowdblclick 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROrganizationPickupGridViewBase
     */
    public grid_rowdblclick($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'rowdblclick', $event);
    }

    /**
     * grid 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROrganizationPickupGridViewBase
     */
    public grid_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'load', $event);
    }

    /**
     * searchform 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROrganizationPickupGridViewBase
     */
    public searchform_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'save', $event);
    }

    /**
     * searchform 部件 search 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROrganizationPickupGridViewBase
     */
    public searchform_search($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'search', $event);
    }

    /**
     * searchform 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROrganizationPickupGridViewBase
     */
    public searchform_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'load', $event);
    }



    /**
     * 是否展开搜索表单
     *
     * @protected
     * @type {boolean}
     * @memberof HROrganizationPickupGridViewBase
     */
    protected isExpandSearchForm: boolean = true;


}